# Skyproj Tutorial

Welcome to `skyproj`!

This is a brief tutorial consisting of ipython notebooks that should get you up to speed with `skyproj` and some of its features.

* [Base Skyproj Class](tutorial_baseclass.ipynb)
* [Surveys](tutorial_surveys.ipynb)
* [HealSparse and Healpix Maps](tutorial_healsparse.ipynb)
